@@ -9,8 +9,8 @@
 #include <cln/real_io.h>
 #include <cln/complex.h>
 #include <cln/complex_io.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 
 // Timings on Linux i486 33 MHz, 1000 decimal places = 104 32-bit words.
