@@ -64,7 +64,7 @@
   #endif
   // Globalize a label defined in the same translation unit.
   // See macro ASM_GLOBALIZE_LABEL in the gcc sources.
-  #if defined(__i386__) || defined(__m68k__) || defined(__mips__) || defined(__mips64__) || defined(__alpha__) || defined(__rs6000__) || defined(__x86_64__) || defined(__s390__)
+  #if defined(__i386__) || defined(__m68k__) || defined(__mips__) || defined(__mipsel__) || defined(__mips64__) || defined(__alpha__) || defined(__rs6000__) || defined(__x86_64__) || defined(__s390__)
     // Some m68k systems use "xdef" or "global" or ".global"...
     #define CL_GLOBALIZE_LABEL(label)  __asm__("\t.globl " label);
   #endif
@@ -85,7 +85,7 @@
     #define CL_GLOBALIZE_LABEL(label)
   #endif
   #if defined(__rs6000__) || defined(_WIN32)
-    #define CL_GLOBALIZE_JUMP_LABEL(label)  CL_GLOBALIZE_LABEL(#label)
+    #define CL_GLOBALIZE_JUMP_LABEL(label)  CL_GLOBALIZE_LABEL(ASM_UNDERSCORE_PREFIX #label)
   #else
     #define CL_GLOBALIZE_JUMP_LABEL(label)
   #endif
@@ -117,13 +117,16 @@
   // except that the latter inhibits inlining of the function containing it
   // in gcc-2.95. For new CPUs, look for "jump" and "indirect_jump" in gcc's
   // machine description.
-  #if defined(__i386__) || defined(__x86_64__)
+  #if defined(__i386__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp %*%0" : : "rm" ((void*)(addr)))
   #endif
+  #if defined(__x86_64__)
+    #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp " ASM_UNDERSCORE_PREFIX #addr)
+  #endif
   #if defined(__m68k__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp %0@" : : "a" ((void*)(addr)))
   #endif
-  #if defined(__mips__)
+  #if defined(__mips__) || defined(__mipsel__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("%*j %0" : : "d" ((void*)(addr)))
   #endif
   #if defined(__sparc__) || defined(__sparc64__)
@@ -134,14 +137,14 @@
   #endif
   #if defined(__hppa__)
     //#define CL_JUMP_TO(addr)  ASM_VOLATILE("bv,n 0(%0)" : : "r" ((void*)(addr)))
-    #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " #addr "\n\tnop")
+    #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " ASM_UNDERSCORE_PREFIX #addr "\n\tnop")
   #endif
   #if defined(__arm__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("mov pc,%0" : : "r" ((void*)(addr)))
   #endif
   #if defined(__rs6000__) || defined(__powerpc__) || defined(__ppc__)
     //#define CL_JUMP_TO(addr)  ASM_VOLATILE("mtctr %0\n\tbctr" : : "r" ((void*)(addr)))
-    #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " #addr)
+    #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " ASM_UNDERSCORE_PREFIX #addr)
   #endif
   #if defined(__m88k__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp %0" : : "r" ((void*)(addr)))
@@ -150,7 +153,7 @@
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp (%0)" : : "r" ((void*)(addr)))
   #endif
   #if defined(__ia64__)
-    #define CL_JUMP_TO(addr)  ASM_VOLATILE("br " #addr)
+    #define CL_JUMP_TO(addr)  ASM_VOLATILE("br " ASM_UNDERSCORE_PREFIX #addr)
   #endif
   #if defined(__s390__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("br %0" : : "a" ((void*)(addr)))
@@ -259,7 +262,7 @@
 //
 // CL_FORCE_LINK(dummy,external_variable)
 // forces a link time reference to the external_variable.
-#include <stdlib.h>
+#include <cstdlib>
 #if 0
 // This definition does not work.  It gets optimized away by g++ 3.1.
 #define CL_FORCE_LINK(dummy,external_variable) \
