@@ -3,9 +3,11 @@
 #ifndef _CL_N_H
 #define _CL_N_H
 
-#include "cl_number.h"
+#include "cln/number.h"
 #include "cl_macros.h"
 
+namespace cln {
+
 nonreturning_function(extern, cl_error_division_by_0, (void));
 nonreturning_function(extern, cl_as_error, (const cl_number& obj, const char * typestring, const char * filename, int line));
 
@@ -18,4 +20,6 @@ nonreturning_function(extern, cl_as_error, (const cl_number& obj, const char * t
     (((((uint32)(msd) << 7) | ((uint32)(msd) >> 25)) ^ ((sint32)(sign) << 30)) + (uintL)(exp))
   #define equal_hashcode_one  equal_hashcode_low(bit(31),1,0)
 
+}  // namespace cln
+
 #endif /* _CL_N_H */
