@@ -9,13 +9,15 @@
 
 // Implementation.
 
-#include "cl_malloc.h"
+#include "cln/malloc.h"
 #include "cl_offsetof.h"
 
+namespace cln {
+
 cl_alloca_header* cl_alloc_alloca_header (size_t size)
 {
 	var cl_alloca_header* pointer =
-	  (cl_alloca_header*)cl_malloc_hook(size+offsetofa(cl_alloca_header,usable_memory));
+	  (cl_alloca_header*)malloc_hook(size+offsetofa(cl_alloca_header,usable_memory));
 	pointer->next = NULL;
 	return pointer;
 }
@@ -24,7 +26,10 @@ void cl_free_alloca_header (cl_alloca_header* pointer)
 {
 	do {
 		cl_alloca_header* next = pointer->next;
-		cl_free_hook(pointer);
+		free_hook(pointer);
 		pointer = next;
 	} while (pointer != NULL);
 }
+
+}  // namespace cln
+
