@@ -156,9 +156,9 @@
 #endif
 
 
-#include "cl_floatparam.h"
-#include "cl_io.h"
-#include "cl_abort.h"
+#include "cln/floatparam.h"
+#include "cln/io.h"
+#include "cln/abort.h"
 
 #if defined(HAVE_LONGDOUBLE) && (long_double_mant_bits > double_mant_bits) && (defined(__i386__) || defined(__m68k__) || (defined(__sparc__) && 0))
 // Only these CPUs have fast "long double"s in hardware.
@@ -663,7 +663,7 @@ static void fill_factor (uintL N, fftc_complex* x, uintL l,
 	if (max_l(2) > intDsize && l > intDsize) {
 		// l > intDsize
 		if (max_l(2) > 64 && l > 64) {
-			fprint(cl_stderr, "FFT problem: l > 64 not supported by pow2_table\n");
+			fprint(std::cerr, "FFT problem: l > 64 not supported by pow2_table\n");
 			cl_abort();
 		}
 		var fftc_real carry = 0;
@@ -944,7 +944,7 @@ static inline void mulu_fftcomplex_nocheck (const uintD* sourceptr1, uintC len1,
 	for ( ; ; k++) {
 		if (k >= sizeof(max_l_table)/sizeof(max_l_table[0])
 		    || max_l_table[k] <= 0) {
-			fprint(cl_stderr, "FFT problem: numbers too big, floating point precision not sufficient\n");
+			fprint(std::cerr, "FFT problem: numbers too big, floating point precision not sufficient\n");
 			cl_abort();
 		}
 		if (2*ceiling((uintL)len1*intDsize,max_l_table[k])-1 <= ((uintL)1 << k))
@@ -1100,7 +1100,7 @@ static void mulu_fftcomplex (const uintD* sourceptr1, uintC len1,
 	var uintD checksum = multiply_checksum(checksum1,checksum2);
 	mulu_fftcomplex_nocheck(sourceptr1,len1,sourceptr2,len2,destptr);
 	if (!(checksum == compute_checksum(destptr,len1+len2))) {
-		fprint(cl_stderr, "FFT problem: checksum error\n");
+		fprint(std::cerr, "FFT problem: checksum error\n");
 		cl_abort();
 	}
 }
