@@ -21,10 +21,14 @@
   #include "cl_asm_i386_.cc"
 #endif
 
-#if defined(__mips__)
+#if defined(__mips__) && !defined(__mipsel__)
   #include "cl_asm_mips_.cc"
 #endif
 
+#if defined(__mipsel__)
+  #include "cl_asm_mipsel_.cc"
+#endif
+
 #if defined(__hppa__)
   #include "cl_asm_hppa_.cc"
 #endif
