@@ -33,7 +33,7 @@ public:
 		: cl_heap_hashtable_2 <key1_type,key2_type,value_type> (),
 		  _maygc_htentry (maygc_htentry)
 	{
-		_garcol_fun = garcol;
+		this->_garcol_fun = garcol;
 	}
 private:
 	// Garbage collection.
@@ -87,7 +87,7 @@ private:
 	{
 		var cl_heap_weak_hashtable_2* ht = (cl_heap_weak_hashtable_2*)_ht;
 		// Now ht->_garcol_fun = garcol_nexttime.
-		ht->_garcol_fun = garcol;
+		ht->_garcol_fun = cl_heap_weak_hashtable_2<key1_type,key2_type,value_type>::garcol;
 		return cl_false;
 	}
 };
