@@ -4,24 +4,28 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_number_io.h"
+#include "cln/number_io.h"
 
 
 // Implementation.
 
-#include "cl_io.h"
-#include "cl_abort.h"
+#include "cln/io.h"
+#include "cln/abort.h"
+
+namespace cln {
 
 void read_number_junk (const char * string_rest, const char * string, const char * string_limit)
 {
-	fprint(cl_stderr, "Junk after number: ");
+	fprint(std::cerr, "Junk after number: ");
 	{ for (const char * ptr = string; ptr != string_rest; ptr++)
-		fprintchar(cl_stderr, *ptr);
+		fprintchar(std::cerr, *ptr);
 	}
-	fprint(cl_stderr, "\"");
+	fprint(std::cerr, "\"");
 	{ for (const char * ptr = string_rest; ptr != string_limit; ptr++)
-		fprintchar(cl_stderr, *ptr);
+		fprintchar(std::cerr, *ptr);
 	}
-	fprint(cl_stderr, "\"\n");
+	fprint(std::cerr, "\"\n");
 	cl_abort();
 }
+
+}  // namespace cln
