@@ -1,4 +1,4 @@
-// cl_default_random_state.
+// default_random_state.
 
 // General includes.
 #include "cl_sysdep.h"
@@ -6,11 +6,15 @@
 CL_PROVIDE(cl_random_def)
 
 // Specification.
-#include "cl_random.h"
+#include "cln/random.h"
 
 
 // Implementation.
 
-cl_random_state cl_default_random_state;
+namespace cln {
+	
+random_state default_random_state;
+
+}  // namespace cln
 
 CL_PROVIDE_END(cl_random_def)
