@@ -4,22 +4,22 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ring.h"
+#include "cln/ring.h"
 
 
 // Implementation.
 
-#include "cl_io.h"
+#include "cln/io.h"
+
+namespace cln {
 
 void cl_ring_element::debug_print () const
 {
 	fprint(cl_debugout, *this);
-	#ifdef CL_IO_IOSTREAM
-	cl_debugout << endl; // newline and flush output
-	#else
-	fprint(cl_debugout, "\n");
-	#endif
+	cl_debugout << std::endl; // newline and flush output
 }
 
-// This dummy links in this module when <cl_ring.h> requires it.
+// This dummy links in this module when <cln/ring.h> requires it.
 int cl_ring_debug_module;
+
+}  // namespace cln
