@@ -9,7 +9,11 @@
 
 // Implementation.
 
+namespace cln {
+
 const cl_N complex_C (const cl_R& a, const cl_R& b)
 {
 	return allocate_complex(a,b);
 }
+
+}  // namespace cln
