@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N operator/ (const cl_N& x, const cl_N& y)
 {
@@ -38,3 +40,5 @@ const cl_N operator/ (const cl_N& x, const cl_N& y)
 		return x * recip(y);
 	}
 }
+
+}  // namespace cln
