@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include <string.h>
+#include <cstring>
 #include "cln/input.h"
 #include "cln/real_io.h"
 #include "cln/float_io.h"
@@ -292,7 +292,6 @@ not_float_syntax:
 		return complex(realpart,imagpart);
 	}
 not_complex_syntax:
-bad_syntax:
 	if (flags.syntax & syntax_maybe_bad) {
 		ASSERT(end_of_parse);
 		*end_of_parse = string;
