@@ -8,9 +8,11 @@
 
 // Implementation.
 
-#include "cl_complex.h"
-#include "cl_io.h"
-#include "cl_complex_io.h"
+#include "cln/complex.h"
+#include "cln/io.h"
+#include "cln/complex_io.h"
+
+namespace cln {
 
 static void dprint (cl_heap* pointer)
 {
@@ -21,10 +23,12 @@ static void dprint (cl_heap* pointer)
 AT_INITIALIZATION(dprint_N)
 { cl_register_type_printer(cl_class_complex,dprint); }
 
-// This dummy links in this module when <cl_complex.h> requires it.
+// This dummy links in this module when <cln/complex.h> requires it.
 int cl_C_debug_module;
 
 extern int cl_R_debug_module;
 static void* dummy[] = { &dummy,
 	&cl_R_debug_module
 };
+
+}  // namespace cln
