@@ -4,15 +4,17 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
 #include "cl_I.h"
 
+namespace cln {
+
 // Methode:
 // Fr y>0:
 //   a:=x, b:=y.
@@ -52,3 +54,5 @@ const cl_N expt (const cl_N& x, const cl_I& y)
 	var cl_N z = expt_pos(x,abs_y); // (expt x (abs y))
 	return (y_negative ? recip(z) : z); // evtl. noch Kehrwert nehmen
 }
+
+}  // namespace cln
