@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N cos (const cl_N& x)
 {
@@ -25,10 +27,12 @@ const cl_N cos (const cl_N& x)
 		// x=a+bi
 		var const cl_R& a = realpart(x);
 		var const cl_R& b = imagpart(x);
-		var cl_cosh_sinh_t hyp_b = cl_cosh_sinh(b); // cosh(b), sinh(b) errechnen
-		var cl_cos_sin_t trig_a = cl_cos_sin(a); // cos(a), sin(a) errechnen
+		var cosh_sinh_t hyp_b = cosh_sinh(b); // cosh(b), sinh(b) errechnen
+		var cos_sin_t trig_a = cos_sin(a); // cos(a), sin(a) errechnen
 		return complex(trig_a.cos * hyp_b.cosh, // cos(a)*cosh(b)
 			       - (trig_a.sin * hyp_b.sinh) // -sin(a)*sinh(b)
 			      );
 	}
 }
+
+}  // namespace cln
