@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N sin (const cl_N& x)
 {
@@ -25,8 +27,8 @@ const cl_N sin (const cl_N& x)
 		// x=a+bi
 		var const cl_R& a = realpart(x);
 		var const cl_R& b = imagpart(x);
-		var cl_cosh_sinh_t hyp_b = cl_cosh_sinh(b); // cosh(b), sinh(b) errechnen
-		var cl_cos_sin_t trig_a = cl_cos_sin(a); // cos(a), sin(a) errechnen
+		var cosh_sinh_t hyp_b = cosh_sinh(b); // cosh(b), sinh(b) errechnen
+		var cos_sin_t trig_a = cos_sin(a); // cos(a), sin(a) errechnen
 		// Da b nicht = Fixnum 0 ist, ist auch sinh(b) nicht = Fixnum 0.
 		// cos(a) /= Fixnum 0.
 		return complex_C(trig_a.sin * hyp_b.cosh, // sin(a)*cosh(b)
@@ -34,3 +36,5 @@ const cl_N sin (const cl_N& x)
 				);
 	}
 }
+
+}  // namespace cln
