@@ -17,13 +17,13 @@ CL_PROVIDE(cl_ieee)
 
 #if (defined(linux) || defined(__linux)) && (defined(FAST_FLOAT) || defined(FAST_DOUBLE))
 
-// Damit Division durch 0.0 ein NaN und kein SIGFPE liefert:
-// Entweder mit -lieee linken,
-// oder libc-linux/sysdeps/linux/{i386,m68k}/ieee.c kopieren:
+// Division by 0.0 should return NaN and not raise an SIGFPE.
+// For this, we either have to link with -lieee or copy some
+// part from libc-linux/sysdeps/linux/{i386,m68k}/ieee.c:
 
 #include <fpu_control.h>
 
-#if 0 // Leider gibt das einen Error, wenn man zustzlich mit -lieee linkt.
+#if 0 // Unfortunately this gives an error if also linked with -lieee
 	#if defined(HAVE_FPU_CONTROL_T)
 		fpu_control_t __fpu_control = _FPU_IEEE;
 	#else
@@ -32,14 +32,19 @@ CL_PROVIDE(cl_ieee)
 #else
 AT_INITIALIZATION(ieee)
 {
-	#if defined(HAVE_FPU_CONTROL_T)
-		extern fpu_control_t __fpu_control;
-		__fpu_control = _FPU_IEEE;
-	#elif defined(HAVE_SETFPUCW)
-		__setfpucw(_FPU_IEEE);
+	#if defined(_FPU_IEEE)
+		#if defined(HAVE_FPU_CONTROL_T)
+			extern fpu_control_t __fpu_control;
+			__fpu_control = _FPU_IEEE;
+		#elif defined(HAVE_SETFPUCW)
+			__setfpucw(_FPU_IEEE);
+		#else
+			extern unsigned short __fpu_control;
+			__fpu_control = _FPU_IEEE;
+		#endif
 	#else
-		extern unsigned short __fpu_control;
-		__fpu_control = _FPU_IEEE;
+		// Nothing to do (as on some architectures):
+		// probably this means that _FPU_DEFAULT is just as good as _FPU_IEEE.
 	#endif
 }
 #endif
