@@ -4,13 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
 
 #include "cl_DF.h"
 #include "cl_ieee.h"
+
+namespace cln {
+
 NEED_IEEE_FLOATS()
 
 const cl_DF operator- (const cl_DF& x1, const cl_DF& x2)
@@ -41,3 +44,5 @@ const cl_DF operator- (const cl_DF& x1, const cl_DF& x2)
 #endif
 #endif
 }
+
+}  // namespace cln
