@@ -4,22 +4,24 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
 #include "cl_I.h"
-#include "cl_sfloat.h"
-#include "cl_ffloat.h"
-#include "cl_dfloat.h"
-#include "cl_lfloat.h"
+#include "cln/sfloat.h"
+#include "cln/ffloat.h"
+#include "cln/dfloat.h"
+#include "cln/lfloat.h"
 #include "cl_F.h"
 #include "cl_SF.h"
 #include "cl_FF.h"
 #include "cl_DF.h"
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_R cl_F_I_mul (const cl_F& x, const cl_I& y)
 {
 	if (eq(y,0)) { return 0; } // x * 0 = exakte 0
@@ -30,3 +32,5 @@ const cl_R cl_F_I_mul (const cl_F& x, const cl_I& y)
 	, /* LF */	return cl_LF_I_mul(x,y);
 	);
 }
+
+}  // namespace cln
