@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
 
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_LF_div_t ceiling2 (const cl_LF& x, const cl_LF& y)
 {
 // Methode:
@@ -20,3 +22,5 @@ const cl_LF_div_t ceiling2 (const cl_LF& x, const cl_LF& y)
 	var cl_LF& r = q_r.remainder;
 	return cl_LF_div_t(q,y*r);
 }
+
+}  // namespace cln
