@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_integer.h"
+#include "cln/integer.h"
 #include "cl_I.h"
 #include "cl_DS.h"
 
@@ -17,6 +17,8 @@
 #define MAYBE_INLINE inline
 #include "cl_LF_minusp.cc"
 
+namespace cln {
+
 const cl_I cl_LF_to_I (const cl_LF& x)
 {
 // Methode:
@@ -43,3 +45,5 @@ const cl_I cl_LF_to_I (const cl_LF& x)
                  minus(uexp, LF_exp_mid + intDsize*(uintL)len)
                 );
 }
+
+}  // namespace cln
