@@ -4,20 +4,22 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat_class.h"
+#include "cln/lfloat_class.h"
 
 
 // Implementation.
 
-#include "cl_lfloat.h"
-#include "cl_input.h"
-#include "cl_float_io.h"
+#include "cln/lfloat.h"
+#include "cln/input.h"
+#include "cln/float_io.h"
+
+namespace cln {
 
 cl_read_flags cl_LF_read_flags = {
 	syntax_lfloat,
 	lsyntax_all,
 	10,
-	{ cl_float_format_lfloat_min, cl_float_format_lfloat_min, cl_false }
+	{ float_format_lfloat_min, float_format_lfloat_min, cl_false }
 };
 
 cl_LF::cl_LF (const char * string)
@@ -25,3 +27,5 @@ cl_LF::cl_LF (const char * string)
 	pointer = as_cl_private_thing(
 		As(cl_LF)(read_float(cl_LF_read_flags,string,NULL,NULL)));
 }
+
+}  // namespace cln
