@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
@@ -13,8 +13,12 @@
 #define MAYBE_INLINE inline
 #include "cl_LF_minusp.cc"
 
+namespace cln {
+
 const cl_LF abs (const cl_LF& x)
 {
 // x<0 -> (- x), x>=0 -> x
 	if (minusp(x)) return -x; else return x;
 }
+
+}  // namespace cln
