@@ -1,16 +1,18 @@
-// as_cl_LF().
+// cl_LF_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 inline cl_boolean cl_LF_p (const cl_number& x)
 {
 	if (x.pointer_p())
@@ -19,7 +21,7 @@ inline cl_boolean cl_LF_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_LF& as_cl_LF (const cl_number& x, const char * filename, int line)
+const cl_LF& cl_LF_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_LF_p(x)) {
 		DeclareType(cl_LF,x);
@@ -27,3 +29,5 @@ const cl_LF& as_cl_LF (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"a long-float number",filename,line);
 }
+
+}  // namespace cln
