@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
@@ -16,9 +16,13 @@
 #define MAYBE_INLINE inline
 #include "cl_LF_minusp.cc"
 
+namespace cln {
+
 MAYBE_INLINE2
 const cl_LF float_sign (const cl_LF& x)
 {
 // Methode: x>=0 -> Ergebnis 1.0; x<0 -> Ergebnis -1.0
 	return encode_LF1s(TheLfloat(x)->sign,TheLfloat(x)->len);
 }
+
+}  // namespace cln
