@@ -4,12 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_F max (const cl_F& x, const cl_F& y)
 {
 	return (x >= y ? x : y);
 }
+
+}  // namespace cln
