@@ -9,9 +9,11 @@
 
 // Implementation.
 
-#include "cl_integer.h"
+#include "cln/integer.h"
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_I cl_SF_to_I (const cl_SF& x)
 {
       // x entpacken:
@@ -27,3 +29,5 @@ const cl_I cl_SF_to_I (const cl_SF& x)
                   exp
                 );
 }
+
+}  // namespace cln
