@@ -1,10 +1,10 @@
-// cl_eulerconst().
+// eulerconst().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -12,12 +12,16 @@
 #include "cl_F.h"
 #include "cl_F_tran.h"
 
-const cl_F cl_eulerconst (cl_float_format_t f)
+namespace cln {
+
+const cl_F eulerconst (float_format_t f)
 {
 	floatformatcase((uintL)f
 	,	return cl_SF_eulerconst;
 	,	return cl_FF_eulerconst;
 	,	return cl_DF_eulerconst;
-	,	return cl_eulerconst(len);
+	,	return eulerconst(len);
 	);
 }
+
+}  // namespace cln
