@@ -1,10 +1,10 @@
-// cl_pi().
+// pi().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -12,12 +12,16 @@
 #include "cl_F.h"
 #include "cl_F_tran.h"
 
-const cl_F cl_pi (void)
+namespace cln {
+
+const cl_F pi (void)
 {
-	floatformatcase(cl_default_float_format
+	floatformatcase(default_float_format
 	,	return cl_SF_pi;
 	,	return cl_FF_pi;
 	,	return cl_DF_pi;
-	,	return cl_pi(len);
+	,	return pi(len);
 	);
 }
+
+}  // namespace cln
