@@ -4,19 +4,21 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer_class.h"
+#include "cln/integer_class.h"
 
 
 // Implementation.
 
-#include "cl_input.h"
-#include "cl_integer_io.h"
+#include "cln/input.h"
+#include "cln/integer_io.h"
+
+namespace cln {
 
 cl_read_flags cl_I_read_flags = {
 	syntax_integer,
 	lsyntax_all,
 	10,
-	{ cl_float_format_ffloat, cl_float_format_lfloat_min, cl_true }
+	{ float_format_ffloat, float_format_lfloat_min, cl_true }
 };
 
 cl_I::cl_I (const char * string)
@@ -24,3 +26,5 @@ cl_I::cl_I (const char * string)
 	pointer = as_cl_private_thing(
 		read_integer(cl_I_read_flags,string,NULL,NULL));
 }
+
+}  // namespace cln
