@@ -4,12 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_I max (const cl_I& x, const cl_I& y)
 {
 	return (x >= y ? x : y);
 }
+
+}  // namespace cln
