@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -12,6 +12,8 @@
 #include "cl_I.h"
 #include "cl_DS.h"
 
+namespace cln {
+
 cl_boolean oddp (const cl_I& x)
 {
 	if (fixnump(x)) {
@@ -28,3 +30,5 @@ cl_boolean oddp (const cl_I& x)
 			return cl_false;
 	}
 }
+
+}  // namespace cln
