@@ -4,14 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer_io.h"
+#include "cln/integer_io.h"
 
 
 // Implementation.
 
-#include "cl_output.h"
+#include "cln/output.h"
 
-void print_integer (cl_ostream stream, const cl_print_real_flags& flags, const cl_I& z)
+namespace cln {
+
+void print_integer (std::ostream& stream, const cl_print_real_flags& flags, const cl_I& z)
 {
 	print_integer(stream,(const cl_print_rational_flags&)flags,z);
 }
+
+}  // namespace cln
