@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer_io.h"
+#include "cln/integer_io.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #include "cl_DS.h"
 #include "cl_sstring.h"
 
+namespace cln {
+
 char * print_integer_to_string (unsigned int base, const cl_I& z)
 {
 	var cl_boolean minus_p = cl_false;
@@ -38,3 +40,5 @@ char * print_integer_to_string (unsigned int base, const cl_I& z)
 	var char* result = cl_sstring(ergptr,erglen); // Ziffern in String schreiben
 	return result;
 }
+
+}  // namespace cln
