@@ -21,6 +21,10 @@ CL_PROVIDE(cl_MI)
 #include "cln/abort.h"
 #include "cl_alloca.h"
 
+// MacOS X does "#define _R 0x00040000L"
+// Grr...
+#undef _R
+
 namespace cln {
 
 cl_heap_modint_ring::cl_heap_modint_ring (cl_I m, cl_modint_setops* setopv, cl_modint_addops* addopv, cl_modint_mulops* mulopv)
