@@ -4,12 +4,14 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_modinteger.h"
+#include "cln/modinteger.h"
 
 
 // Implementation.
 
-#include "cl_integer.h"
+#include "cln/integer.h"
+
+namespace cln {
 
 const cl_MI operator<< (const cl_MI& x, sintL y) // assume 0 <= y < 2^31
 {
@@ -29,3 +31,5 @@ const cl_MI operator<< (const cl_MI& x, sintL y) // assume 0 <= y < 2^31
 	else
 		return x * expt_pos(R->canonhom(2), (cl_I)(long)y);
 }
+
+}  // namespace cln
