@@ -9,7 +9,11 @@
 
 // Implementation.
 
+namespace cln {
+
 const cl_RA I_I_to_RT (const cl_I& a, const cl_I& b)
 {
 	return allocate_ratio(a,b);
 }
+
+}  // namespace cln
