@@ -4,15 +4,17 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
 #include "cl_RA.h"
-#include "cl_integer.h"
+#include "cln/integer.h"
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_RA operator- (const cl_RA& r, const cl_RA& s)
 {
 #if 0
@@ -108,3 +110,5 @@ const cl_RA operator- (const cl_RA& r, const cl_RA& s)
 	}
 #endif
 }
+
+}  // namespace cln
