@@ -4,19 +4,21 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational_class.h"
+#include "cln/rational_class.h"
 
 
 // Implementation.
 
-#include "cl_input.h"
-#include "cl_rational_io.h"
+#include "cln/input.h"
+#include "cln/rational_io.h"
+
+namespace cln {
 
 cl_read_flags cl_RA_read_flags = {
 	syntax_rational,
 	lsyntax_all,
 	10,
-	{ cl_float_format_ffloat, cl_float_format_lfloat_min, cl_true }
+	{ float_format_ffloat, float_format_lfloat_min, cl_true }
 };
 
 cl_RA::cl_RA (const char * string)
@@ -24,3 +26,5 @@ cl_RA::cl_RA (const char * string)
 	pointer = as_cl_private_thing(
 		read_rational(cl_RA_read_flags,string,NULL,NULL));
 }
+
+}  // namespace cln
