@@ -1,16 +1,18 @@
-// as_cl_RA().
+// cl_RA_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 // Cf. cl_RA_p in cl_RA_ring.cc.
 // But here, for better inlining in g++, it is preferrable to finish every
 // alternative with either "return cl_true;" or "return cl_false;".
@@ -28,7 +30,7 @@ inline cl_boolean cl_RA_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_RA& as_cl_RA (const cl_number& x, const char * filename, int line)
+const cl_RA& cl_RA_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_RA_p(x)) {
 		DeclareType(cl_RA,x);
@@ -36,3 +38,5 @@ const cl_RA& as_cl_RA (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"a rational number",filename,line);
 }
+
+}  // namespace cln
