@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
 #include "cl_RA.h"
 
+namespace cln {
+
 static void ratio_destructor (cl_heap* pointer)
 {
 	(*(cl_heap_ratio*)pointer).~cl_heap_ratio();
@@ -20,3 +22,5 @@ cl_class cl_class_ratio = {
 	ratio_destructor,
 	cl_class_flags_subclass_complex | cl_class_flags_subclass_real | cl_class_flags_subclass_rational
 };
+
+}  // namespace cln
