@@ -4,14 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
-#include "cl_float.h"
-#include "cl_rational.h"
+#include "cln/float.h"
+#include "cln/rational.h"
+
+namespace cln {
 
 #undef MAYBE_INLINE
 #define MAYBE_INLINE inline
@@ -19,3 +21,5 @@
 
 const cl_R sqrt (const cl_R& x)
 GEN_R_OP1_2(x, sqrt, return)
+
+}  // namespace cln
