@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
@@ -15,6 +15,8 @@
 
 #if 0
 
+namespace cln {
+
 const cl_LF cl_R_to_LF (const cl_R& x, uintC len)
 {
 	if (rationalp(x)) {
@@ -26,11 +28,15 @@ const cl_LF cl_R_to_LF (const cl_R& x, uintC len)
 	}
 }
 
+}  // namespace cln
+
 #else // fully inlined, faster
 
 #include "cl_RA.h"
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_LF cl_R_to_LF (const cl_R& x, uintC len)
 {
 	realcase6(x
@@ -43,4 +49,6 @@ const cl_LF cl_R_to_LF (const cl_R& x, uintC len)
 	);
 }
 
+}  // namespace cln
+
 #endif
