@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
@@ -23,5 +23,9 @@
 #include "cl_DF_eqhashcode.cc"
 #include "cl_LF_eqhashcode.cc"
 
-uint32 cl_equal_hashcode (const cl_R& x)
-GEN_R_OP1_7(x, cl_equal_hashcode, return)
+namespace cln {
+
+uint32 equal_hashcode (const cl_R& x)
+GEN_R_OP1_7(x, equal_hashcode, return)
+
+}  // namespace cln
