@@ -4,14 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
-#include "cl_rational.h"
-#include "cl_integer.h"
+#include "cln/rational.h"
+#include "cln/integer.h"
+
+namespace cln {
 
 // Methode:
 // Fr y>0:
@@ -52,3 +54,5 @@ const cl_R expt (const cl_R& x, sintL y)
 	var cl_R z = expt_pos(x,abs_y); // (expt x (abs y))
 	return (y<0 ? recip(z) : z); // evtl. noch Kehrwert nehmen
 }
+
+}  // namespace cln
