@@ -4,14 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_R atan (const cl_R& x)
 {
 // Methode:
 // arctan(x) = arctan(X=1,Y=x).
 	return atan(1,x);
 }
+
+}  // namespace cln
