@@ -19,19 +19,12 @@
   #else
     extern "C" int gettimeofday (struct timeval * tp, GETTIMEOFDAY_TZP_T tzp);
   #endif
-#elif defined(HAVE_FTIME)
-  #include <sys/timeb.h>
-  #ifdef _WIN32
-    extern "C" void ftime (struct timeb * tp);
-  #else
-    extern "C" int ftime (struct timeb * tp);
-  #endif
 #else
-  #include <time.h>
+  #include <ctime>
 #endif
 #ifdef HAVE_PERROR_DECL
-  #include <errno.h>
-  #include <stdio.h>
+  #include <cerrno>
+  #include <cstdio>
 #else
   extern "C" int perror (const char *);
 #endif
@@ -49,12 +42,6 @@ const cl_timespec cl_current_time ()
 	return cl_timespec(tv.tv_sec,
 			   tv.tv_usec * (1000000000/1000000)
 			  );
-#elif defined(HAVE_FTIME)
-	var struct timeb timebuf;
-	ftime(&timebuf);
-	return cl_timespec(timebuf.time,
-			   (uintL)timebuf.millitm * (1000000000/1000)
-			  );
 #else
 	return cl_timespec(time(NULL),0);
 #endif
