@@ -2,10 +2,11 @@
 #include <cln/io.h>
 #include <cln/float.h>
 #include <cln/real.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 #include "cl_LF.h"
+using namespace cln;
 
 int main (int argc, char * argv[])
 {
